game_qu.getting_started API documentation

# Module `game_qu.getting_started`

## Sub-modules

`game_qu.getting_started.getting_started`

  Summary This game engine is compartmentalized. There is almost total freedom for making games with this engine. Components like collision detection, …

`game_qu.getting_started.pong (example game)`

  This is an example of a simple game of pong made using the game engine. Click the see 'Expand Source Code' button below to see the code.